Face Statements — Calcbench API Client documentation

# Face Statements

The data behind the https://www.calcbench.com/detail/ page.

calcbench.face_statement(company_identifier, statement_type, period_type='annual', all_history=False, descending_dates=False)

  Face Statements.

  face statements as reported by the filing company

  Parameters

    - company_identifier (string) – a ticker or a CIK code, eg ‘msft’

    - statement_type (string) – one of (‘income’, ‘balance’, ‘cash’, ‘change-in-equity’, ‘comprehensive-income’)

    - period_type (string) – annual|quarterly|cummulative|combined

    - all_periods (string) – get all history or only the last four, True or False.

    - descending_dates (bool) – return columns in oldest -> newest order.

  Return type

    object

  Returns: An object with columns and line items lists. The columns have fiscal_period, period_start, period_end and instant values. The line items have label, local_name (the XBRL tag name), tree_depth (the indent amount), is_subtotal (whether or not the line item is computed from above metrics) and facts. The facts are in the same order as the columns and have fact_ids (an internal Calcbench ID), unit_of_measure (USD etc), effective_value (the reported value), and format_type.

  Usage::

        >>> calcbench.face_statement('msft', 'income')